/*!
 * OpenUI5
 * (c) Copyright 2009-2025 SAP SE or an SAP affiliate company.
 * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
 */

@import "../base/library.source.less";
@import "../../../../../sap/ui/core/themes/sap_fiori_3_dark/base.less";
@import "../../../../../sap/ui/core/themes/sap_fiori_3_dark/global.less";

@_sap_ui_table_DeleteIcon: decline;

@import "Cell.less";
@import "Row.less";
@import "RowSelection.less";
@import "Table.less";