/*!
 * OpenUI5
 * (c) Copyright 2009-2025 SAP SE or an SAP affiliate company.
 * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
 */

@import "../base/library.source.less";
@import "../../../../sap/ui/core/themes/sap_fiori_3_dark/base.less";
@import "../../../../sap/ui/core/themes/sap_fiori_3_dark/global.less";

@import "ActionListItem.less";
@import "ActionSelect.less";
@import "ActionSheet.less";
@import "ActionTile.less";
@import "Avatar.less";
@import "Bar.less";
@import "BusyDialog.less";
@import "BusyIndicator.less";
@import "Button.less";
@import "Carousel.less";
@import "CheckBox.less";
@import "ColorPalette.less";
@import "CustomTile.less";
@import "Dialog.less";
@import "DraftIndicator.less";
@import "MessagePage.less";
@import "GenericTag.less";
@import "GenericTile.less";
@import "GroupHeaderListItem.less";
@import "FeedInput.less";
@import "HeaderContainer.less";
@import "IconTabBar.less";
@import "InputBase.less";

/* note: the following two files are not in alphabetical order and should be imported after InputBase.less */
@import "ComboBoxBase.less";
@import "ColumnListItem.less";
@import "LightBox.less";
@import "Link.less";
@import "ListBase.less";
@import "ListItemBase.less";
@import "MenuButton.less";
@import "MenuListItem.less";
@import "MessageBox.less";
@import "MessageStrip.less";
@import "MessageView.less";
@import "MessageToast.less";
@import "NewsContent.less";
@import "NotificationListGroup.less";
@import "ObjectAttribute.less";
@import "ObjectHeader.less";
@import "ObjectMarker.less";
@import "ObjectStatus.less";
@import "OverflowToolbarAssociativePopover.less";
@import "Page.less";
@import "Panel.less";
@import "PlanningCalendar.less";
@import "Popover.less";
@import "ProgressIndicator.less";
@import "PullToRefresh.less";
@import "QuickView.less";
@import "RadioButton.less";
@import "RadioButtonGroup.less";
@import "RangeSlider.less";
@import "RatingIndicator.less";
@import "ResponsivePopover.less";
@import "ScrollContainer.less";
@import "SearchField.less";
@import "SegmentedButton.less";
@import "Select.less";
@import "SelectDialog.less";
@import "SelectList.less";
@import "Shell.less";
@import "SinglePlanningCalendarGrid.less";
@import "SinglePlanningCalendarMonthGrid.less";
@import "Slider.less";
@import "SliderTooltip.less";
@import "SlideTile.less";
@import "SplitButton.less";
@import "StandardListItem.less";
@import "StandardTile.less";
@import "Switch.less";
@import "Table.less";
@import "TableSelectDialog.less";
@import "TabStrip.less";
@import "TabContainer.less";
@import "Text.less";
@import "TextArea.less";
@import "TileContent.less";
@import "TileContainer.less";
@import "TimePicker.less";
@import "TimePickerSliders.less";
@import "ToggleButton.less";
@import "Token.less";
@import "Tokenizer.less";
@import "Toolbar.less";
@import "UploadCollection.less";
@import "ValueStateMessage.less";
@import "ViewSettingsDialog.less";
@import "WheelSlider.less";
@import "Wizard.less";
@import "WizardProgressNavigator.less";